@@ -76,8 +76,10 @@ static NSMutableDictionary *_extensionMapping = nil;
 
 + (void)setTarExecutable:(NSString *)newTar
 {
-	[self checkExecutable:newTar withName:@"tar"];
-	[[NSUserDefaults standardUserDefaults] setObject:newTar forKey:PREF_KEY_TAR];
+	if (newTar != nil)
+	{
+		[[NSUserDefaults standardUserDefaults] setObject:newTar forKey:PREF_KEY_TAR];
+	}
 }
 
 + (BOOL)isBsdTar;
@@ -111,8 +113,28 @@ static NSMutableDictionary *_extensionMapping = nil;
 
 + (void)setZipExecutable:(NSString *)newZip
 {
-	[self checkExecutable:newZip withName:@"zip"];
-	[[NSUserDefaults standardUserDefaults] setObject:newZip forKey:PREF_KEY_ZIP];
+	if (newZip != nil)
+	{
+		[[NSUserDefaults standardUserDefaults] setObject:newZip forKey:PREF_KEY_ZIP];
+	}
+}
+
++ (NSString *)sevenZipExecutable;
+{
+	NSString *zip = [self stringForKey:PREF_KEY_SEVEN_ZIP];
+	if (zip == nil)
+	{
+		zip = [[NSFileManager defaultManager] locateExecutable:@"7z"];
+	}
+	return zip;
+}
+
++ (void)setSevenZipExecutable:(NSString *)new7zip
+{
+	if (new7zip != nil)
+	{
+		[[NSUserDefaults standardUserDefaults] setObject:new7zip forKey:PREF_KEY_SEVEN_ZIP];
+	}
 }
 
 + (NSString *)rarExecutable;
@@ -127,8 +149,10 @@ static NSMutableDictionary *_extensionMapping = nil;
 
 + (void)setRarExecutable:(NSString *)newRar;
 {
-	[self checkExecutable:newRar withName:@"rar"];
-	[[NSUserDefaults standardUserDefaults] setObject:newRar forKey:PREF_KEY_RAR];
+	if (newRar != nil)
+	{
+		[[NSUserDefaults standardUserDefaults] setObject:newRar forKey:PREF_KEY_RAR];
+	}
 }
 
 + (NSString *)lhaExecutable
@@ -143,8 +167,10 @@ static NSMutableDictionary *_extensionMapping = nil;
 
 + (void)setLhaExecutable:(NSString *)newLha;
 {
-	[self checkExecutable:newLha withName:@"lha"];
-	[[NSUserDefaults standardUserDefaults] setObject:newLha forKey:PREF_KEY_LHA];
+	if (newLha != nil)
+	{
+		[[NSUserDefaults standardUserDefaults] setObject:newLha forKey:PREF_KEY_LHA];
+	}
 }
 
 + (NSString *)lzxExecutable
@@ -159,8 +185,10 @@ static NSMutableDictionary *_extensionMapping = nil;
 
 + (void)setLzxExecutable:(NSString *)newLzx;
 {
-	[self checkExecutable:newLzx withName:@"unlzx"];
-	[[NSUserDefaults standardUserDefaults] setObject:newLzx forKey:PREF_KEY_LZX];
+	if (newLzx != nil)
+	{
+		[[NSUserDefaults standardUserDefaults] setObject:newLzx forKey:PREF_KEY_LZX];
+	}
 }
 
 + (NSString *)gzipExecutable
@@ -175,8 +203,10 @@ static NSMutableDictionary *_extensionMapping = nil;
 
 + (void)setGzipExecutable:(NSString *)newGzip
 {
-	[self checkExecutable:newGzip withName:@"gzip"];
-	[[NSUserDefaults standardUserDefaults] setObject:newGzip forKey:PREF_KEY_GZIP];
+	if (newGzip != nil)
+	{
+		[[NSUserDefaults standardUserDefaults] setObject:newGzip forKey:PREF_KEY_GZIP];
+	}
 }
 
 + (NSString *)lastOpenDirectory
@@ -257,22 +287,4 @@ static NSMutableDictionary *_extensionMapping = nil;
 	return [[NSUserDefaults standardUserDefaults] boolForKey:key];
 }
 
-+ (void)checkExecutable:(NSString *)executable withName:(NSString *)name;
-{
-	if (executable == nil)
-	{
-		[NSException raise:X_MISSING_PREF format:@"No excutable for %@ specified!", name];
-	}
-	if ([[NSFileManager defaultManager] fileExistsAtPath:executable] == NO)
-	{
-		[NSException raise:X_WRONG_PREF
-			format:@"Executable for %@ at path '%@' does not exist", name, executable];
-	}
-	if ([[NSFileManager defaultManager] isExecutableFileAtPath:executable] == NO)
-	{
-		[NSException raise:X_WRONG_PREF 
-			format:@"Executable for %@ at path '%@' is not executable", name, executable];
-	}
-}
-
 @end
