@@ -13,6 +13,7 @@
 	IBOutlet NSTextField *_rarTextField;
 	IBOutlet NSTextField *_lhaTextField;
 	IBOutlet NSTextField *_lzxTextField;
+	IBOutlet NSTextField *_sevenZipTextField;
 	
 	// this holds a reference to an Archive subclass that the user
 	// needs to set before he can leave the prefs dialog
@@ -20,7 +21,6 @@
 }
 
 - (void)showPreferencesPanel;
-- (void)setArchiveForRequiredType:(Class)archive;
 		
 @end
 
