@@ -9,6 +9,8 @@
 // parsing routine
 #define MINI_UNZIP_IDENTIFIER @"MiniUnz"
 
+static NSData *_magicBytes = nil;
+
 @interface ZipArchive (PrivateAPI)
 - (NSData *)dataByRunningUnzip;
 - (NSArray *)listUnzipContents:(NSArray *)lines;
@@ -21,6 +23,10 @@
  */
 + (void)initialize
 {
+	// zip files start with 'P K 0x003 0x004'
+	char zipBytes[] = { 'P', 'K', 0x003, 0x004 };
+	_magicBytes = [[NSData dataWithBytes:zipBytes length:4] retain];
+	
 	[self registerFileExtension:@"zip" forArchiveClass:self];
 	[self registerFileExtension:@"jar" forArchiveClass:self];
 }
@@ -41,6 +47,11 @@
 	return @"Zip";
 }
 
++ (NSData *)magicBytes
+{
+	return _magicBytes;
+}
+
 //------------------------------------------------------------------------------
 // expanding the archive
 //------------------------------------------------------------------------------
