@@ -30,7 +30,7 @@ tar cf - Zipper | (cd $tempdir; tar xf -)
 
 # remove stuff that's not to be included into distro tarball
 cd $tempdir
-find . -name CVS -exec rm -r {} \; 2> /dev/null
+find . -name \.svn -exec rm -rf {} \; 2> /dev/null
 cd Zipper
 rm -r .xvpics .cvsignore .dir.tiff
 rm -r Site/.xvpics
